@@ -73,7 +73,6 @@
 #include <KMessageBox>
 #include <KMimeTypeTrader>
 #include <KProcess>
-#include <KRecentFilesAction>
 #include <KRun>
 #include <KSelectAction>
 #include <KService>
@@ -1017,7 +1016,7 @@ void KeysManager::addToKAB()
 
 void KeysManager::slotAddressbookSearchResult(KJob *job)
 {
-	KGpgNode * const nd = m_addIds.value(job, 0);
+	KGpgNode * const nd = m_addIds.value(job, nullptr);
 
 	if (!nd)
 		return;
@@ -1471,7 +1470,7 @@ void KeysManager::slotexport()
 			expopts << QLatin1String( "--export-options" ) << exportAttr;
 
 		if (page->checkServer->isChecked()) {
-			KeyServer *expServer = new KeyServer(0, imodel);
+			KeyServer *expServer = new KeyServer(nullptr, imodel);
 			expServer->slotSetExportAttribute(exportAttr);
 			expServer->slotSetKeyserver(page->destServer->currentText());
 
@@ -2130,7 +2129,7 @@ void KeysManager::importallsignkey()
 		return;
 	}
 
-	importRemoteKeys(missingKeys.toList());
+	importRemoteKeys(missingKeys.values());
 }
 
 void KeysManager::preimportsignkey()
